import * as Core from "./core.js";
import * as Errors from "./error.js";
import { type Agent } from "./_shims/index.js";
import * as Uploads from "./uploads.js";
import * as Pagination from 'cloudflare/pagination';
import * as API from 'cloudflare/resources/index';
export interface ClientOptions {
    /**
     * Defaults to process.env['CLOUDFLARE_API_KEY'].
     */
    apiKey?: string | null | undefined;
    /**
     * Defaults to process.env['CLOUDFLARE_EMAIL'].
     */
    apiEmail?: string | null | undefined;
    /**
     * Defaults to process.env['CLOUDFLARE_API_TOKEN'].
     */
    apiToken?: string | null | undefined;
    /**
     * Defaults to process.env['CLOUDFLARE_API_USER_SERVICE_KEY'].
     */
    userServiceKey?: string | null | undefined;
    /**
     * Override the default base URL for the API, e.g., "https://api.example.com/v2/"
     *
     * Defaults to process.env['CLOUDFLARE_BASE_URL'].
     */
    baseURL?: string | null | undefined;
    /**
     * The maximum amount of time (in milliseconds) that the client should wait for a response
     * from the server before timing out a single request.
     *
     * Note that request timeouts are retried by default, so in a worst-case scenario you may wait
     * much longer than this timeout before the promise succeeds or fails.
     */
    timeout?: number;
    /**
     * An HTTP agent used to manage HTTP(S) connections.
     *
     * If not provided, an agent will be constructed by default in the Node.js environment,
     * otherwise no agent is used.
     */
    httpAgent?: Agent;
    /**
     * Specify a custom `fetch` function implementation.
     *
     * If not provided, we use `node-fetch` on Node.js and otherwise expect that `fetch` is
     * defined globally.
     */
    fetch?: Core.Fetch | undefined;
    /**
     * The maximum number of times that the client will retry a request in case of a
     * temporary failure, like a network error or a 5XX error from the server.
     *
     * @default 2
     */
    maxRetries?: number;
    /**
     * Default headers to include with every request to the API.
     *
     * These can be removed in individual requests by explicitly setting the
     * header to `undefined` or `null` in request options.
     */
    defaultHeaders?: Core.Headers;
    /**
     * Default query parameters to include with every request to the API.
     *
     * These can be removed in individual requests by explicitly setting the
     * param to `undefined` in request options.
     */
    defaultQuery?: Core.DefaultQuery;
}
/** API Client for interfacing with the Cloudflare API. */
export declare class Cloudflare extends Core.APIClient {
    apiKey: string | null;
    apiEmail: string | null;
    apiToken: string | null;
    userServiceKey: string | null;
    private _options;
    /**
     * API Client for interfacing with the Cloudflare API.
     *
     * @param {string | null | undefined} [opts.apiKey=process.env['CLOUDFLARE_API_KEY'] ?? null]
     * @param {string | null | undefined} [opts.apiEmail=process.env['CLOUDFLARE_EMAIL'] ?? null]
     * @param {string | null | undefined} [opts.apiToken=process.env['CLOUDFLARE_API_TOKEN'] ?? null]
     * @param {string | null | undefined} [opts.userServiceKey=process.env['CLOUDFLARE_API_USER_SERVICE_KEY'] ?? null]
     * @param {string} [opts.baseURL=process.env['CLOUDFLARE_BASE_URL'] ?? https://api.cloudflare.com/client/v4] - Override the default base URL for the API.
     * @param {number} [opts.timeout=1 minute] - The maximum amount of time (in milliseconds) the client will wait for a response before timing out.
     * @param {number} [opts.httpAgent] - An HTTP agent used to manage HTTP(s) connections.
     * @param {Core.Fetch} [opts.fetch] - Specify a custom `fetch` function implementation.
     * @param {number} [opts.maxRetries=2] - The maximum number of times the client will retry a request.
     * @param {Core.Headers} opts.defaultHeaders - Default headers to include with every request to the API.
     * @param {Core.DefaultQuery} opts.defaultQuery - Default query parameters to include with every request to the API.
     */
    constructor({ baseURL, apiKey, apiEmail, apiToken, userServiceKey, ...opts }?: ClientOptions);
    accounts: API.Accounts;
    originCACertificates: API.OriginCACertificates;
    ips: API.IPs;
    memberships: API.Memberships;
    user: API.UserResource;
    zones: API.Zones;
    loadBalancers: API.LoadBalancers;
    cache: API.Cache;
    ssl: API.SSL;
    subscriptions: API.Subscriptions;
    acm: API.ACM;
    argo: API.Argo;
    availablePlans: API.AvailablePlans;
    availableRatePlans: API.AvailableRatePlans;
    certificateAuthorities: API.CertificateAuthorities;
    clientCertificates: API.ClientCertificates;
    customCertificates: API.CustomCertificates;
    customHostnames: API.CustomHostnames;
    customNameservers: API.CustomNameservers;
    dns: API.DNS;
    dnssec: API.DNSSEC;
    emailRouting: API.EmailRouting;
    filters: API.Filters;
    firewall: API.Firewall;
    healthchecks: API.Healthchecks;
    keylessCertificates: API.KeylessCertificates;
    logpush: API.Logpush;
    logs: API.Logs;
    originTLSClientAuth: API.OriginTLSClientAuth;
    pagerules: API.Pagerules;
    rateLimits: API.RateLimits;
    secondaryDNS: API.SecondaryDNS;
    waitingRooms: API.WaitingRooms;
    web3: API.Web3;
    workers: API.Workers;
    kv: API.KV;
    durableObjects: API.DurableObjects;
    queues: API.Queues;
    managedHeaders: API.ManagedHeaders;
    pageShield: API.PageShield;
    rulesets: API.Rulesets;
    urlNormalization: API.URLNormalization;
    spectrum: API.Spectrum;
    addressing: API.Addressing;
    auditLogs: API.AuditLogs;
    billing: API.Billing;
    brandProtection: API.BrandProtection;
    diagnostics: API.Diagnostics;
    images: API.Images;
    intel: API.Intel;
    magicTransit: API.MagicTransit;
    magicNetworkMonitoring: API.MagicNetworkMonitoring;
    mtlsCertificates: API.MTLSCertificates;
    pages: API.Pages;
    pcaps: API.PCAPs;
    registrar: API.Registrar;
    requestTracers: API.RequestTracers;
    rules: API.Rules;
    storage: API.Storage;
    stream: API.Stream;
    alerting: API.Alerting;
    d1: API.D1;
    r2: API.R2;
    warpConnector: API.WARPConnector;
    workersForPlatforms: API.WorkersForPlatforms;
    zeroTrust: API.ZeroTrust;
    challenges: API.Challenges;
    hyperdrive: API.Hyperdrive;
    rum: API.RUM;
    vectorize: API.Vectorize;
    urlScanner: API.URLScanner;
    radar: API.Radar;
    botManagement: API.BotManagement;
    originPostQuantumEncryption: API.OriginPostQuantumEncryption;
    speed: API.Speed;
    dcvDelegation: API.DCVDelegation;
    hostnames: API.Hostnames;
    snippets: API.Snippets;
    calls: API.Calls;
    cloudforceOne: API.CloudforceOne;
    protected defaultQuery(): Core.DefaultQuery | undefined;
    protected defaultHeaders(opts: Core.FinalRequestOptions): Core.Headers;
    protected validateHeaders(headers: Core.Headers, customHeaders: Core.Headers): void;
    protected authHeaders(opts: Core.FinalRequestOptions): Core.Headers;
    protected apiEmailAuth(opts: Core.FinalRequestOptions): Core.Headers;
    protected apiKeyAuth(opts: Core.FinalRequestOptions): Core.Headers;
    protected apiTokenAuth(opts: Core.FinalRequestOptions): Core.Headers;
    protected userServiceKeyAuth(opts: Core.FinalRequestOptions): Core.Headers;
    protected stringifyQuery(query: Record<string, unknown>): string;
    static Cloudflare: typeof Cloudflare;
    static CloudflareError: typeof Errors.CloudflareError;
    static APIError: typeof Errors.APIError;
    static APIConnectionError: typeof Errors.APIConnectionError;
    static APIConnectionTimeoutError: typeof Errors.APIConnectionTimeoutError;
    static APIUserAbortError: typeof Errors.APIUserAbortError;
    static NotFoundError: typeof Errors.NotFoundError;
    static ConflictError: typeof Errors.ConflictError;
    static RateLimitError: typeof Errors.RateLimitError;
    static BadRequestError: typeof Errors.BadRequestError;
    static AuthenticationError: typeof Errors.AuthenticationError;
    static InternalServerError: typeof Errors.InternalServerError;
    static PermissionDeniedError: typeof Errors.PermissionDeniedError;
    static UnprocessableEntityError: typeof Errors.UnprocessableEntityError;
}
export declare const CloudflareError: typeof Errors.CloudflareError, APIError: typeof Errors.APIError, APIConnectionError: typeof Errors.APIConnectionError, APIConnectionTimeoutError: typeof Errors.APIConnectionTimeoutError, APIUserAbortError: typeof Errors.APIUserAbortError, NotFoundError: typeof Errors.NotFoundError, ConflictError: typeof Errors.ConflictError, RateLimitError: typeof Errors.RateLimitError, BadRequestError: typeof Errors.BadRequestError, AuthenticationError: typeof Errors.AuthenticationError, InternalServerError: typeof Errors.InternalServerError, PermissionDeniedError: typeof Errors.PermissionDeniedError, UnprocessableEntityError: typeof Errors.UnprocessableEntityError;
export import toFile = Uploads.toFile;
export import fileFromPath = Uploads.fileFromPath;
export declare namespace Cloudflare {
    export import toFile = Uploads.toFile;
    export import fileFromPath = Uploads.fileFromPath;
    export import RequestOptions = Core.RequestOptions;
    export import V4PagePagination = Pagination.V4PagePagination;
    export import V4PagePaginationParams = Pagination.V4PagePaginationParams;
    export import V4PagePaginationResponse = Pagination.V4PagePaginationResponse;
    export import V4PagePaginationArray = Pagination.V4PagePaginationArray;
    export import V4PagePaginationArrayParams = Pagination.V4PagePaginationArrayParams;
    export import V4PagePaginationArrayResponse = Pagination.V4PagePaginationArrayResponse;
    export import CursorPagination = Pagination.CursorPagination;
    export import CursorPaginationParams = Pagination.CursorPaginationParams;
    export import CursorPaginationResponse = Pagination.CursorPaginationResponse;
    export import CursorLimitPagination = Pagination.CursorLimitPagination;
    export import CursorLimitPaginationParams = Pagination.CursorLimitPaginationParams;
    export import CursorLimitPaginationResponse = Pagination.CursorLimitPaginationResponse;
    export import SinglePage = Pagination.SinglePage;
    export import SinglePageResponse = Pagination.SinglePageResponse;
    export import Accounts = API.Accounts;
    export import Account = API.Account;
    export import AccountUpdateResponse = API.AccountUpdateResponse;
    export import AccountListResponse = API.AccountListResponse;
    export import AccountGetResponse = API.AccountGetResponse;
    export import AccountListResponsesV4PagePaginationArray = API.AccountListResponsesV4PagePaginationArray;
    export import AccountUpdateParams = API.AccountUpdateParams;
    export import AccountListParams = API.AccountListParams;
    export import AccountGetParams = API.AccountGetParams;
    export import OriginCACertificates = API.OriginCACertificates;
    export import OriginCACertificate = API.OriginCACertificate;
    export import OriginCACertificateCreateResponse = API.OriginCACertificateCreateResponse;
    export import OriginCACertificateListResponse = API.OriginCACertificateListResponse;
    export import OriginCACertificateDeleteResponse = API.OriginCACertificateDeleteResponse;
    export import OriginCACertificateGetResponse = API.OriginCACertificateGetResponse;
    export import OriginCACertificateCreateParams = API.OriginCACertificateCreateParams;
    export import IPs = API.IPs;
    export import JDCloudIPs = API.JDCloudIPs;
    export import IPListResponse = API.IPListResponse;
    export import IPListParams = API.IPListParams;
    export import Memberships = API.Memberships;
    export import Membership = API.Membership;
    export import MembershipUpdateResponse = API.MembershipUpdateResponse;
    export import MembershipDeleteResponse = API.MembershipDeleteResponse;
    export import MembershipGetResponse = API.MembershipGetResponse;
    export import MembershipsV4PagePaginationArray = API.MembershipsV4PagePaginationArray;
    export import MembershipUpdateParams = API.MembershipUpdateParams;
    export import MembershipListParams = API.MembershipListParams;
    export import UserResource = API.UserResource;
    export import User = API.User;
    export import UserEditResponse = API.UserEditResponse;
    export import UserGetResponse = API.UserGetResponse;
    export import UserEditParams = API.UserEditParams;
    export import Zones = API.Zones;
    export import Zone = API.Zone;
    export import ZoneCreateResponse = API.ZoneCreateResponse;
    export import ZoneListResponse = API.ZoneListResponse;
    export import ZoneDeleteResponse = API.ZoneDeleteResponse;
    export import ZoneEditResponse = API.ZoneEditResponse;
    export import ZoneGetResponse = API.ZoneGetResponse;
    export import ZoneListResponsesV4PagePaginationArray = API.ZoneListResponsesV4PagePaginationArray;
    export import ZoneCreateParams = API.ZoneCreateParams;
    export import ZoneListParams = API.ZoneListParams;
    export import ZoneDeleteParams = API.ZoneDeleteParams;
    export import ZoneEditParams = API.ZoneEditParams;
    export import ZoneGetParams = API.ZoneGetParams;
    export import LoadBalancers = API.LoadBalancers;
    export import LoadBalancer = API.LoadBalancer;
    export import LoadBalancerListResponse = API.LoadBalancerListResponse;
    export import LoadBalancerDeleteResponse = API.LoadBalancerDeleteResponse;
    export import LoadBalancerCreateParams = API.LoadBalancerCreateParams;
    export import LoadBalancerUpdateParams = API.LoadBalancerUpdateParams;
    export import LoadBalancerListParams = API.LoadBalancerListParams;
    export import LoadBalancerDeleteParams = API.LoadBalancerDeleteParams;
    export import LoadBalancerEditParams = API.LoadBalancerEditParams;
    export import LoadBalancerGetParams = API.LoadBalancerGetParams;
    export import Cache = API.Cache;
    export import CachePurgeResponse = API.CachePurgeResponse;
    export import CachePurgeParams = API.CachePurgeParams;
    export import SSL = API.SSL;
    export import Subscriptions = API.Subscriptions;
    export import SubscriptionCreateResponse = API.SubscriptionCreateResponse;
    export import SubscriptionUpdateResponse = API.SubscriptionUpdateResponse;
    export import SubscriptionListResponse = API.SubscriptionListResponse;
    export import SubscriptionDeleteResponse = API.SubscriptionDeleteResponse;
    export import SubscriptionGetResponse = API.SubscriptionGetResponse;
    export import SubscriptionCreateParams = API.SubscriptionCreateParams;
    export import SubscriptionUpdateParams = API.SubscriptionUpdateParams;
    export import ACM = API.ACM;
    export import Argo = API.Argo;
    export import AvailablePlans = API.AvailablePlans;
    export import BillSubsAPIAvailableRatePlan = API.BillSubsAPIAvailableRatePlan;
    export import AvailablePlanListResponse = API.AvailablePlanListResponse;
    export import AvailableRatePlans = API.AvailableRatePlans;
    export import BillSubsRatePlan = API.BillSubsRatePlan;
    export import AvailableRatePlanGetResponse = API.AvailableRatePlanGetResponse;
    export import CertificateAuthorities = API.CertificateAuthorities;
    export import ClientCertificates = API.ClientCertificates;
    export import TLSCertificatesAndHostnamesClientCertificate = API.TLSCertificatesAndHostnamesClientCertificate;
    export import TLSCertificatesAndHostnamesClientCertificatesV4PagePaginationArray = API.TLSCertificatesAndHostnamesClientCertificatesV4PagePaginationArray;
    export import ClientCertificateCreateParams = API.ClientCertificateCreateParams;
    export import ClientCertificateListParams = API.ClientCertificateListParams;
    export import ClientCertificateDeleteParams = API.ClientCertificateDeleteParams;
    export import ClientCertificateEditParams = API.ClientCertificateEditParams;
    export import ClientCertificateGetParams = API.ClientCertificateGetParams;
    export import CustomCertificates = API.CustomCertificates;
    export import TLSCertificatesAndHostnamesCustomCertificate = API.TLSCertificatesAndHostnamesCustomCertificate;
    export import CustomCertificateCreateResponse = API.CustomCertificateCreateResponse;
    export import CustomCertificateDeleteResponse = API.CustomCertificateDeleteResponse;
    export import CustomCertificateEditResponse = API.CustomCertificateEditResponse;
    export import CustomCertificateGetResponse = API.CustomCertificateGetResponse;
    export import TLSCertificatesAndHostnamesCustomCertificatesV4PagePaginationArray = API.TLSCertificatesAndHostnamesCustomCertificatesV4PagePaginationArray;
    export import CustomCertificateCreateParams = API.CustomCertificateCreateParams;
    export import CustomCertificateListParams = API.CustomCertificateListParams;
    export import CustomCertificateDeleteParams = API.CustomCertificateDeleteParams;
    export import CustomCertificateEditParams = API.CustomCertificateEditParams;
    export import CustomCertificateGetParams = API.CustomCertificateGetParams;
    export import CustomHostnames = API.CustomHostnames;
    export import TLSCertificatesAndHostnamesCustomHostname = API.TLSCertificatesAndHostnamesCustomHostname;
    export import CustomHostnameCreateResponse = API.CustomHostnameCreateResponse;
    export import CustomHostnameListResponse = API.CustomHostnameListResponse;
    export import CustomHostnameDeleteResponse = API.CustomHostnameDeleteResponse;
    export import CustomHostnameEditResponse = API.CustomHostnameEditResponse;
    export import CustomHostnameGetResponse = API.CustomHostnameGetResponse;
    export import CustomHostnameListResponsesV4PagePaginationArray = API.CustomHostnameListResponsesV4PagePaginationArray;
    export import CustomHostnameCreateParams = API.CustomHostnameCreateParams;
    export import CustomHostnameListParams = API.CustomHostnameListParams;
    export import CustomHostnameDeleteParams = API.CustomHostnameDeleteParams;
    export import CustomHostnameEditParams = API.CustomHostnameEditParams;
    export import CustomHostnameGetParams = API.CustomHostnameGetParams;
    export import CustomNameservers = API.CustomNameservers;
    export import DNSCustomNameserversCustomNS = API.DNSCustomNameserversCustomNS;
    export import CustomNameserverDeleteResponse = API.CustomNameserverDeleteResponse;
    export import CustomNameserverAvailabiltyResponse = API.CustomNameserverAvailabiltyResponse;
    export import CustomNameserverGetResponse = API.CustomNameserverGetResponse;
    export import CustomNameserverVerifyResponse = API.CustomNameserverVerifyResponse;
    export import CustomNameserverCreateParams = API.CustomNameserverCreateParams;
    export import CustomNameserverDeleteParams = API.CustomNameserverDeleteParams;
    export import CustomNameserverAvailabiltyParams = API.CustomNameserverAvailabiltyParams;
    export import CustomNameserverGetParams = API.CustomNameserverGetParams;
    export import CustomNameserverVerifyParams = API.CustomNameserverVerifyParams;
    export import DNS = API.DNS;
    export import DNSSEC = API.DNSSEC;
    export import DNSSECDNSSEC = API.DNSSECDNSSEC;
    export import DNSSECDeleteResponse = API.DNSSECDeleteResponse;
    export import DNSSECDeleteParams = API.DNSSECDeleteParams;
    export import DNSSECEditParams = API.DNSSECEditParams;
    export import DNSSECGetParams = API.DNSSECGetParams;
    export import EmailRouting = API.EmailRouting;
    export import Filters = API.Filters;
    export import LegacyJhsFilter = API.LegacyJhsFilter;
    export import FilterCreateResponse = API.FilterCreateResponse;
    export import LegacyJhsFiltersV4PagePaginationArray = API.LegacyJhsFiltersV4PagePaginationArray;
    export import FilterCreateParams = API.FilterCreateParams;
    export import FilterUpdateParams = API.FilterUpdateParams;
    export import FilterListParams = API.FilterListParams;
    export import Firewall = API.Firewall;
    export import Healthchecks = API.Healthchecks;
    export import HealthchecksHealthchecks = API.HealthchecksHealthchecks;
    export import HealthcheckListResponse = API.HealthcheckListResponse;
    export import HealthcheckDeleteResponse = API.HealthcheckDeleteResponse;
    export import HealthcheckCreateParams = API.HealthcheckCreateParams;
    export import HealthcheckUpdateParams = API.HealthcheckUpdateParams;
    export import HealthcheckEditParams = API.HealthcheckEditParams;
    export import KeylessCertificates = API.KeylessCertificates;
    export import TLSCertificatesAndHostnamesBase = API.TLSCertificatesAndHostnamesBase;
    export import TLSCertificatesAndHostnamesKeylessCertificate = API.TLSCertificatesAndHostnamesKeylessCertificate;
    export import KeylessCertificateListResponse = API.KeylessCertificateListResponse;
    export import KeylessCertificateDeleteResponse = API.KeylessCertificateDeleteResponse;
    export import KeylessCertificateCreateParams = API.KeylessCertificateCreateParams;
    export import KeylessCertificateListParams = API.KeylessCertificateListParams;
    export import KeylessCertificateDeleteParams = API.KeylessCertificateDeleteParams;
    export import KeylessCertificateEditParams = API.KeylessCertificateEditParams;
    export import KeylessCertificateGetParams = API.KeylessCertificateGetParams;
    export import Logpush = API.Logpush;
    export import Logs = API.Logs;
    export import OriginTLSClientAuth = API.OriginTLSClientAuth;
    export import TLSCertificatesAndHostnamesZoneAuthenticatedOriginPull = API.TLSCertificatesAndHostnamesZoneAuthenticatedOriginPull;
    export import OriginTLSClientAuthCreateResponse = API.OriginTLSClientAuthCreateResponse;
    export import OriginTLSClientAuthListResponse = API.OriginTLSClientAuthListResponse;
    export import OriginTLSClientAuthDeleteResponse = API.OriginTLSClientAuthDeleteResponse;
    export import OriginTLSClientAuthGetResponse = API.OriginTLSClientAuthGetResponse;
    export import OriginTLSClientAuthCreateParams = API.OriginTLSClientAuthCreateParams;
    export import OriginTLSClientAuthListParams = API.OriginTLSClientAuthListParams;
    export import OriginTLSClientAuthDeleteParams = API.OriginTLSClientAuthDeleteParams;
    export import OriginTLSClientAuthGetParams = API.OriginTLSClientAuthGetParams;
    export import Pagerules = API.Pagerules;
    export import ZonesPageRule = API.ZonesPageRule;
    export import PageruleCreateResponse = API.PageruleCreateResponse;
    export import PageruleUpdateResponse = API.PageruleUpdateResponse;
    export import PageruleListResponse = API.PageruleListResponse;
    export import PageruleDeleteResponse = API.PageruleDeleteResponse;
    export import PageruleEditResponse = API.PageruleEditResponse;
    export import PageruleGetResponse = API.PageruleGetResponse;
    export import PageruleCreateParams = API.PageruleCreateParams;
    export import PageruleUpdateParams = API.PageruleUpdateParams;
    export import PageruleListParams = API.PageruleListParams;
    export import PageruleDeleteParams = API.PageruleDeleteParams;
    export import PageruleEditParams = API.PageruleEditParams;
    export import PageruleGetParams = API.PageruleGetParams;
    export import RateLimits = API.RateLimits;
    export import LegacyJhsRateLimits = API.LegacyJhsRateLimits;
    export import RateLimitCreateResponse = API.RateLimitCreateResponse;
    export import RateLimitListResponse = API.RateLimitListResponse;
    export import RateLimitDeleteResponse = API.RateLimitDeleteResponse;
    export import RateLimitEditResponse = API.RateLimitEditResponse;
    export import RateLimitGetResponse = API.RateLimitGetResponse;
    export import RateLimitListResponsesV4PagePaginationArray = API.RateLimitListResponsesV4PagePaginationArray;
    export import RateLimitCreateParams = API.RateLimitCreateParams;
    export import RateLimitListParams = API.RateLimitListParams;
    export import RateLimitEditParams = API.RateLimitEditParams;
    export import SecondaryDNS = API.SecondaryDNS;
    export import WaitingRooms = API.WaitingRooms;
    export import WaitingroomWaitingroom = API.WaitingroomWaitingroom;
    export import WaitingRoomListResponse = API.WaitingRoomListResponse;
    export import WaitingRoomDeleteResponse = API.WaitingRoomDeleteResponse;
    export import WaitingRoomCreateParams = API.WaitingRoomCreateParams;
    export import WaitingRoomUpdateParams = API.WaitingRoomUpdateParams;
    export import WaitingRoomEditParams = API.WaitingRoomEditParams;
    export import Web3 = API.Web3;
    export import Workers = API.Workers;
    export import KV = API.KV;
    export import DurableObjects = API.DurableObjects;
    export import Queues = API.Queues;
    export import WorkersQueue = API.WorkersQueue;
    export import WorkersQueueCreated = API.WorkersQueueCreated;
    export import WorkersQueueUpdated = API.WorkersQueueUpdated;
    export import QueueListResponse = API.QueueListResponse;
    export import QueueDeleteResponse = API.QueueDeleteResponse;
    export import QueueCreateParams = API.QueueCreateParams;
    export import QueueUpdateParams = API.QueueUpdateParams;
    export import QueueListParams = API.QueueListParams;
    export import QueueDeleteParams = API.QueueDeleteParams;
    export import QueueGetParams = API.QueueGetParams;
    export import ManagedHeaders = API.ManagedHeaders;
    export import ManagedHeaderListResponse = API.ManagedHeaderListResponse;
    export import ManagedHeaderEditResponse = API.ManagedHeaderEditResponse;
    export import ManagedHeaderListParams = API.ManagedHeaderListParams;
    export import ManagedHeaderEditParams = API.ManagedHeaderEditParams;
    export import PageShield = API.PageShield;
    export import PageShieldGetZoneSettings = API.PageShieldGetZoneSettings;
    export import PageShieldUpdateZoneSettings = API.PageShieldUpdateZoneSettings;
    export import PageShieldUpdateParams = API.PageShieldUpdateParams;
    export import PageShieldGetParams = API.PageShieldGetParams;
    export import Rulesets = API.Rulesets;
    export import RulesetsRulesetResponse = API.RulesetsRulesetResponse;
    export import RulesetsRulesetsResponse = API.RulesetsRulesetsResponse;
    export import RulesetCreateParams = API.RulesetCreateParams;
    export import RulesetUpdateParams = API.RulesetUpdateParams;
    export import RulesetListParams = API.RulesetListParams;
    export import RulesetDeleteParams = API.RulesetDeleteParams;
    export import RulesetGetParams = API.RulesetGetParams;
    export import URLNormalization = API.URLNormalization;
    export import URLNormalizationUpdateResponse = API.URLNormalizationUpdateResponse;
    export import URLNormalizationGetResponse = API.URLNormalizationGetResponse;
    export import URLNormalizationUpdateParams = API.URLNormalizationUpdateParams;
    export import URLNormalizationGetParams = API.URLNormalizationGetParams;
    export import Spectrum = API.Spectrum;
    export import Addressing = API.Addressing;
    export import AuditLogs = API.AuditLogs;
    export import AuditLogListResponse = API.AuditLogListResponse;
    export import AuditLogListResponsesV4PagePaginationArray = API.AuditLogListResponsesV4PagePaginationArray;
    export import AuditLogListParams = API.AuditLogListParams;
    export import Billing = API.Billing;
    export import BrandProtection = API.BrandProtection;
    export import IntelPhishingURLInfo = API.IntelPhishingURLInfo;
    export import IntelPhishingURLSubmit = API.IntelPhishingURLSubmit;
    export import BrandProtectionSubmitParams = API.BrandProtectionSubmitParams;
    export import BrandProtectionURLInfoParams = API.BrandProtectionURLInfoParams;
    export import Diagnostics = API.Diagnostics;
    export import Images = API.Images;
    export import Intel = API.Intel;
    export import MagicTransit = API.MagicTransit;
    export import MagicNetworkMonitoring = API.MagicNetworkMonitoring;
    export import MTLSCertificates = API.MTLSCertificates;
    export import TLSCertificatesAndHostnamesCertificateObjectPost = API.TLSCertificatesAndHostnamesCertificateObjectPost;
    export import TLSCertificatesAndHostnamesComponentsSchemasCertificateObject = API.TLSCertificatesAndHostnamesComponentsSchemasCertificateObject;
    export import MTLSCertificateListResponse = API.MTLSCertificateListResponse;
    export import MTLSCertificateCreateParams = API.MTLSCertificateCreateParams;
    export import MTLSCertificateListParams = API.MTLSCertificateListParams;
    export import MTLSCertificateDeleteParams = API.MTLSCertificateDeleteParams;
    export import MTLSCertificateGetParams = API.MTLSCertificateGetParams;
    export import Pages = API.Pages;
    export import PCAPs = API.PCAPs;
    export import PCAPCreateResponse = API.PCAPCreateResponse;
    export import PCAPListResponse = API.PCAPListResponse;
    export import PCAPGetResponse = API.PCAPGetResponse;
    export import PCAPCreateParams = API.PCAPCreateParams;
    export import PCAPListParams = API.PCAPListParams;
    export import PCAPGetParams = API.PCAPGetParams;
    export import Registrar = API.Registrar;
    export import RequestTracers = API.RequestTracers;
    export import Rules = API.Rules;
    export import Storage = API.Storage;
    export import Stream = API.Stream;
    export import StreamVideos = API.StreamVideos;
    export import StreamListResponse = API.StreamListResponse;
    export import StreamCreateParams = API.StreamCreateParams;
    export import StreamListParams = API.StreamListParams;
    export import StreamDeleteParams = API.StreamDeleteParams;
    export import StreamGetParams = API.StreamGetParams;
    export import Alerting = API.Alerting;
    export import D1 = API.D1;
    export import R2 = API.R2;
    export import WARPConnector = API.WARPConnector;
    export import WARPConnectorCreateResponse = API.WARPConnectorCreateResponse;
    export import WARPConnectorListResponse = API.WARPConnectorListResponse;
    export import WARPConnectorDeleteResponse = API.WARPConnectorDeleteResponse;
    export import WARPConnectorEditResponse = API.WARPConnectorEditResponse;
    export import WARPConnectorGetResponse = API.WARPConnectorGetResponse;
    export import WARPConnectorTokenResponse = API.WARPConnectorTokenResponse;
    export import WARPConnectorListResponsesV4PagePaginationArray = API.WARPConnectorListResponsesV4PagePaginationArray;
    export import WARPConnectorCreateParams = API.WARPConnectorCreateParams;
    export import WARPConnectorListParams = API.WARPConnectorListParams;
    export import WARPConnectorDeleteParams = API.WARPConnectorDeleteParams;
    export import WARPConnectorEditParams = API.WARPConnectorEditParams;
    export import WARPConnectorGetParams = API.WARPConnectorGetParams;
    export import WARPConnectorTokenParams = API.WARPConnectorTokenParams;
    export import WorkersForPlatforms = API.WorkersForPlatforms;
    export import ZeroTrust = API.ZeroTrust;
    export import Challenges = API.Challenges;
    export import Hyperdrive = API.Hyperdrive;
    export import RUM = API.RUM;
    export import Vectorize = API.Vectorize;
    export import URLScanner = API.URLScanner;
    export import URLScannerScanResponse = API.URLScannerScanResponse;
    export import URLScannerScanParams = API.URLScannerScanParams;
    export import Radar = API.Radar;
    export import BotManagement = API.BotManagement;
    export import BotManagementUpdateResponse = API.BotManagementUpdateResponse;
    export import BotManagementGetResponse = API.BotManagementGetResponse;
    export import BotManagementUpdateParams = API.BotManagementUpdateParams;
    export import BotManagementGetParams = API.BotManagementGetParams;
    export import OriginPostQuantumEncryption = API.OriginPostQuantumEncryption;
    export import OriginPostQuantumEncryptionUpdateResponse = API.OriginPostQuantumEncryptionUpdateResponse;
    export import OriginPostQuantumEncryptionGetResponse = API.OriginPostQuantumEncryptionGetResponse;
    export import OriginPostQuantumEncryptionUpdateParams = API.OriginPostQuantumEncryptionUpdateParams;
    export import OriginPostQuantumEncryptionGetParams = API.OriginPostQuantumEncryptionGetParams;
    export import Speed = API.Speed;
    export import ObservatorySchedule = API.ObservatorySchedule;
    export import ObservatoryTrend = API.ObservatoryTrend;
    export import SpeedDeleteResponse = API.SpeedDeleteResponse;
    export import SpeedDeleteParams = API.SpeedDeleteParams;
    export import SpeedScheduleGetParams = API.SpeedScheduleGetParams;
    export import SpeedTrendsListParams = API.SpeedTrendsListParams;
    export import DCVDelegation = API.DCVDelegation;
    export import Hostnames = API.Hostnames;
    export import Snippets = API.Snippets;
    export import Snippet = API.Snippet;
    export import SnippetListResponse = API.SnippetListResponse;
    export import SnippetDeleteResponse = API.SnippetDeleteResponse;
    export import SnippetUpdateParams = API.SnippetUpdateParams;
    export import Calls = API.Calls;
    export import CallsApp = API.CallsApp;
    export import CallsAppWithSecret = API.CallsAppWithSecret;
    export import CallListResponse = API.CallListResponse;
    export import CallCreateParams = API.CallCreateParams;
    export import CallUpdateParams = API.CallUpdateParams;
    export import CallListParams = API.CallListParams;
    export import CallDeleteParams = API.CallDeleteParams;
    export import CallGetParams = API.CallGetParams;
    export import CloudforceOne = API.CloudforceOne;
}
export default Cloudflare;
//# sourceMappingURL=index.d.ts.map